pub struct Capability {
pub max_concurrent_requests: Option<u32>,
pub max_calls_in_request: Option<u32>,
pub max_size_request: Option<u64>,
pub max_size_upload: Option<u64>,
pub max_objects_in_get: Option<u32>,
pub max_objects_in_set: Option<u32>,
pub collation_algorithms: Option<Vec<String>>,
}Expand description
Capability object
Fields
max_concurrent_requests: Option<u32>Maximum number of concurrent requests
max_calls_in_request: Option<u32>Maximum number of method calls per request
max_size_request: Option<u64>Maximum size of a request in bytes
max_size_upload: Option<u64>Maximum size of a blob upload in bytes
max_objects_in_get: Option<u32>Maximum number of objects to return in a single get/query call
max_objects_in_set: Option<u32>Maximum number of objects to return in a single set call
collation_algorithms: Option<Vec<String>>Collation algorithms supported