pub enum JmapErrorType {
NotJson,
NotRequest,
Limit,
UnknownCapability,
UnknownMethod,
InvalidArguments,
AccountNotFound,
AccountNotSupportedByMethod,
AccountReadOnly,
ServerFail,
ServerUnavailable,
ServerPartialFailure,
}Expand description
JMAP error types as defined in RFC 8620 Section 3.6
Variants
NotJson
The content type of the request was not “application/json” or the request did not parse as I-JSON.
NotRequest
The request parsed as JSON but did not match the structure defined in RFC 8620 Section 3.3.
Limit
The server has a limit on the number of calls in a single request
UnknownCapability
Unknown capability in “using” property
UnknownMethod
Unknown method
InvalidArguments
Invalid arguments to method
AccountNotFound
Account not found or does not support this data type
AccountNotSupportedByMethod
Account not supported by this method
AccountReadOnly
Account is read-only
ServerFail
Server error
Server is unavailable
ServerPartialFailure
Server has a hard limit on the number of objects
Implementations